SELECT * FROM exttable('/tmp/sample.txt', '\t') AS 
( date, Ū text , Ū text,  integer);

SELECT * FROM exttable('/tmp/sample.txt', '\t') AS 
( date, Ū text , Ū text,  integer)
ORDER BY ;

DROP VIEW ;

CREATE VIEW  AS 
       SELECT * FROM exttable('/tmp/sample.txt', '\t') AS 
       ( date, Ū text , Ū text,  integer);

SELECT * FROM  ORDER BY ;
